<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="stockMainTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>

<script>
import { fetchList, delObj } from '@/api/warehouse/stockmain'
import TableForm from './stockmain-form'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import { remote } from '../../../api/admin/dict'
import { loadLocation, loadWarehouse } from '../../../api/warehouse/location'
export default {
  data() {
    return {
      ajaxFun: fetchList,
      locations: [],
      warehouseOptions: [],
      locTypeOptions: [],
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 库位编号
          {
            minWidth: '140',
            prop: 'locNo',
            label: '库位编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            formatter: this.getLocName,
            optList: () => {
              return this.getLocNameList()
            },
            render: { fun: this.addOrUpdateHandle }
          },
          // 库位描述
          {
            minWidth: '120',
            prop: 'locDesc',
            label: '库位描述',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 库位类型
          {
            minWidth: '200',
            prop: 'locType',
            label: '库位类型',
            sort: true,
            isTrue: true,
            isSearch: true,
            formatter: this.locationType,
            searchInfoType: 'text'
          },
          // 备注
          {
            minWidth: '140',
            prop: 'locRemark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 所属仓库分组
          {
            minWidth: '120',
            prop: 'locGroup',
            label: '所属仓库分组',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            formatter: this.warehouseLocGroup,
            optList: () => {
              return this.getWarehouseLocGroupList()
            }
          },
          // 零件编号
          {
            minWidth: '200',
            prop: 'partNo',
            label: '零件编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 零件名称
          {
            minWidth: '140',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 规格
          {
            minWidth: '120',
            prop: 'specs',
            label: '规格',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 最高安全库存
          {
            minWidth: '200',
            prop: 'highQty',
            label: '最高安全库存',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 最低安全库存
          {
            minWidth: '200',
            prop: 'lowQty',
            label: '最低安全库存',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 申请批量
          {
            minWidth: '200',
            prop: 'batchQty',
            label: '申请批量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 单位
          {
            minWidth: '200',
            prop: 'unit',
            label: '单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getUnitList()
            }
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 200,
          minWidth: 200
        }
      },
      addOrUpdateVisible: false,
      unitList: [
        {
          value: '盒',
          label: '盒'
        },
        {
          value: '卷',
          label: '卷'
        },
        {
          value: '只',
          label: '只'
        },
        {
          value: '件',
          label: '件'
        }
      ]
    }
  },
  components: {
    ttable,
    TableForm
  },
  created() {
    this.getLocTypeCache('warehouse_type') // 获取定时任务运行时状态
    this.initWarehouseSelect()
    this.initLocationSelect()
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 选中库位行
    handleSelectionChange(val) {
      this.mulLocation = val
    },
    // 获取库位的数据
    initLocationSelect() {
      loadLocation().then((res) => {
        this.locations = JSON.parse(
          JSON.stringify(res.data.data)
            .replace(/locNo/g, 'value')
            .replace(/locName/g, 'label')
        )
      })
    },
    getLocNameList() {
      return this.locations
    },
    // 将id进行匹配显示为对应的库位名称
    getLocName(row, column, cellValue) {
      this.locations.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    // 获取仓库的数据
    initWarehouseSelect() {
      loadWarehouse().then((res) => {
        this.warehouseOptions = JSON.parse(
          JSON.stringify(res.data)
            .replace(/id/g, 'value')
            .replace(/warehouseName/g, 'label')
        )
      })
    },
    getWarehouseLocGroupList() {
      return this.warehouseOptions
    },
    // 将id进行匹配显示为对应的仓库分组
    warehouseLocGroup(row, column, cellValue) {
      this.warehouseOptions.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    /**
     * 获取字典显示名称并缓存
     */
    getLocTypeCache(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.locTypeOptions = _data
        }
      })
    },
    /**
     * 获取字典定时任务执行状态字典值显示名称
     */
    locationType(row, column, cellValue) {
      this.locTypeOptions.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    // 获取数据列表
    getData() {
      this.$refs.stockMainTable.getDataList()
    },
    // 单位下拉框查询
    getUnitList() {
      return this.unitList
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除ID为' + row.id, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    }
  }
}
</script>
